[otrs-cvs] ITSMConfigurationManagement/Kernel/System/ITSMConfigItem Version.pm, 1.34, 1.35

"CVS commits notifications of OTRS.org" <[email protected]> Fri, 7 Jun 2013 11:51:01 +0000
Newsgroups gmane.comp.otrs.cvs
Message-ID <[email protected]>
Comments:
Update of /home/cvs/ITSMConfigurationManagement/Kernel/System/ITSMConfigItem
In directory lancelot:/tmp/cvs-serv16698/Kernel/System/ITSMConfigItem

Modified Files:
	Version.pm 
Log Message:
Fixed bug# 9507 - Sorting CIs by Last Changed Time shows an error message.

Author: ub

Index: Version.pm
===================================================================
RCS file: /home/cvs/ITSMConfigurationManagement/Kernel/System/ITSMConfigItem/Version.pm,v
retrieving revision 1.34
retrieving revision 1.35
diff -2 -u -d -r1.34 -r1.35
--- Version.pm	30 Nov 2012 19:49:09 -0000	1.34
+++ Version.pm	7 Jun 2013 11:50:56 -0000	1.35
@@ -1,5 +1,5 @@
 # --
 # Kernel/System/ITSMConfigItem/Version.pm - sub module of ITSMConfigItem.pm with version functions
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
 # --
 # $Id$
@@ -772,5 +772,6 @@
         OrderBy => [ 'ConfigItemID', 'Number' ],                  # (optional)
         # default: [ 'ConfigItemID' ]
         # (ConfigItemID, Name, Number, ClassID, DeplStateID, InciStateID)
 
         # Additional information for OrderBy:
@@ -836,4 +837,9 @@
         DeplStateID  => 'vr.depl_state_id',
         InciStateID  => 'vr.inci_state_id',
+        CreateTime   => 'ci.create_time',
+        CreateBy     => 'ci.create_by',
+        ChangeTime   => 'vr.create_time'
+        ,    # the change time of the CI is the same as the create time of the version!
+        ChangeBy => 'ci.change_by',
     );
 
---------------------------------------------------------------------
@@ -772,5 +772,6 @@
         OrderBy => [ 'ConfigItemID', 'Number' ],                  # (optional)
         # default: [ 'ConfigItemID' ]
-        # (ConfigItemID, Name, Number, ClassID, DeplStateID, InciStateID)
+        # (ConfigItemID, Name, Number, ClassID, DeplStateID, InciStateID
+        # CreateTime, CreateBy, ChangeTime, ChangeBy)
 
         # Additional information for OrderBy:
OTRS mailing list: cvs-log - Webpage: http://otrs.org/
Archive: http://lists.otrs.org/pipermail/cvs-log
To unsubscribe: http://lists.otrs.org/cgi-bin/listinfo/cvs-log